==> aisleriot-3.14.2p1.tgz: lib/aisleriot/guile/2.0/fortunes.go <==
GOOF----BE-4-2.0      ] C 4   h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  ice-9	g  format	
 	 	g  initialize-playing-area	g  set-ace-high	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-blank-slot	g  add-extended-slot	g  down	g  give-status-message	g  new-game	g  set-statusbar-message	g  get-stock-no-string	g  
string-append	g  _	 f  Stock left:	!f   	"g  number->string	#g  length	$g  	get-cards	%g  empty-slot?	&g  button-pressed	'g  
droppable?	(g  
move-n-cards!	)g  button-released	*g  member	+			 	,g  
removable?	-g  get-suit	.g  get-top-card	/g  	get-value	0g  remove-card	1g  
add-to-score!	2g  
deal-cards	3g  
flip-top-card	4g  button-clicked	5g  button-double-clicked	6g  game-won	7g  	game-over	8g  hint-remove-top-card	9g  
check-hint	:f  ,Consider moving something into an empty slot	;f  Deal another round	<g  get-hint	=g  get-options	>g  
apply-options	?g  timeout	@g  set-features	Ag  droppable-feature	Bg  
set-lambdaC 5  h     ] 4	 >  "  G       h      ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4	>  "  G  4	>  "  G  4	>  "  G  4	>  "  G  4
>   "  G  		 C       g  filenamef  fortunes.scm
	
							#			3			C			U			e			h			o			x			{		 		 		 		 		 		 		 		 	!	 	#	 	 
  g  nameg  new-game CR        h      n] 45 6        f    g  filenamef  fortunes.scm
	&
		'			'	 		
  g  nameg  give-status-message CR !"#$     h       ] 45444
5556        g  filenamef  fortunes.scm
	)
		*				*			*		
	*	"		+			+	!		+	)		+	!		+			*	 		
  g  nameg  get-stock-no-string CR% h   P  ]
$  E 
$  ;45$  C4	5$  C4	5$  C	6CC        g  slot-id
		O g  	card-list		O g  t			K g  t		(	K g  t		:	K  g  filenamef  fortunes.scm
	-
		.			/			.			0			0		"	1		(	0		4	2		:	0		K	3	 		O	  g  nameg  button-pressed C&R'(  h   0   ]4 5$  4 >  "  G  CC            g  
start-slot
		+ g  	card-list		+ g  end-slot			+  g  filenamef  fortunes.scm
	5
		6			6			8	 		+	  g  nameg  button-released C)R*+%   h   (   ]45$   $  C6C             g  
start-slot
		" g  	card-list		" g  end-slot			"  g  filenamef  fortunes.scm
	<
		=				=			=			=			>			=		 	?	 			"	  g  nameg  
droppable? C'R,%-./01        h     w] $  	$  C 645$  "  ;44 554455$  44 554455"  $  4 >  "  G  6	$  C 6         o    g  slot-id
	  g  reason	   g  filenamef  fortunes.scm
	A
		B			B			C	
		C			E			E	
	 	F		*	F	
	0	G		3	G		;	G		<	H		?	H		G	H		H	G		L	F	
	M	I		P	I		X	I		Y	J		\	J		d	J		e	I		n	F		o	L	 	M	 	N	 	N	
 	P	" 	P	  	 	  g  nameg  
removable? C,R%2+3,        h   p   ]4 5$  C 
$  N4
>  "  G  4>  "  G  4	>  "  G  4	>  "  G  	6 6           g  slot-id
		l  g  filenamef  fortunes.scm
	R
		S		
	S			U	
		U			W			W		"	W		+	X		<	Y		N	Z		e	[		l	\	
 		l  g  nameg  button-clicked C4R4        h      {] 6   s    g  slot
		  g  filenamef  fortunes.scm
	^
		_	 		  g  nameg  button-double-clicked C5R%#$        h   X   ] 4
5$  J4455$  744	55$  #44	55$  44	55CCCCC       g  filenamef  fortunes.scm
	a
		b			b			c			c			c			c			b			d		"	d		*	d		+	d		/	b		1	e		4	e		<	e		=	e		A	b		C	f		F	f		N	f		O	f	 		X
  g  nameg  game-won C6R%-.      h  (  ]] 4>   "  G  4
5$ 45$  "  4	5$  "  4	5$  "  4	5$  "  445544	55$  "  445544	55$  "  445544	55$  "  ^44	5544	55$  "  <44	5544	55$  "  44	5544	55"  C       U    g  filenamef  fortunes.scm
	h
		i			j			j			k		&	k		,	l		6	k		<	m		F	k		L	n		V	k		\	o		_	o	'	f	o		g	p		j	p	'	r	p		s	o		w	k		}	q	 	q	' 	q	 	r	 	r	' 	r	 	q	 	k	 	s	 	s	' 	s	 	t	 	t	' 	t	 	s	 	k	 	u	 	u	' 	u	 	v	 	v	' 	v	 	u	 	k	 	w	 	w	' 	w	 	x	 	x	' 	x	 	w	 	k		y		y	'	y		z		z	'	z		y		y	"	j	 >	#
  g  nameg  	game-over C7R%-./89        h     `]	$  C4 5$  "  )45$  "  44 554455$  )44 554455$   66 6      X    g  slot1
		| g  slot2		|  g  filenamef  fortunes.scm
	|
		}			}							
	 		(		
	. 		1 		9 		: 		= 		E 		F 		J			K 		N 		V 		W 		Z 		b 		c 		g 	
	m 		s 		z 		| 	
 		|	  g  nameg  
check-hint C9R9%#$:;   h  p  ]4	5  $   C4		5  $   C4		5  $   C45  $  "  54	5$  "  4	5$  "  4	5 $  45$  "  
4455  $  "  z4	5$  "  44	55$  "  L4	5$  "  44	55$  "  4	5$  "  44	55 $  
45 "  "    $   C4
5$  C
45 C        g  t
	
n g  t
	n g  t
	2n g  t
	C  g  t	W  g  t		k  g  t
 2 g  t / g  t	 , g  t
Kn  
g  filenamef  fortunes.scm
 
	 		
 		 		 		* 		2 		> 		C 		Q 		W 		e 		k 		y 	  	  	  	  	  	#  	  	  	  	  	  	  	#  	  	  	  	  	  	  	#  	  	  	 	 	 	 	#' 	) 	6 	
8 	< 	> 	A 	
K 	W 	` 	d 	h 	j 	m 	
 7	n
  g  nameg  get-hint C<R   h      W] C       O    g  filenamef  fortunes.scm
 
 		
  g  nameg  get-options C=R    h      o]C       g    g  options
		  g  filenamef  fortunes.scm
 
 		  g  nameg  
apply-options C>R    h      S] C       K    g  filenamef  fortunes.scm
 
 		
  g  nameg  timeout C?R4@iAi>  "  G  Bii&i)i4i5i7i6i<i=i>i?i'i6             g  filenamef  fortunes.scm		
	
	&
	)
	-
	5
	<
	B	A

	R
>	^
	a
P	h
S	|
 
J 
 
> 
? 
 
 	
   C6 

==> aisleriot-3.20.2.tgz: lib/aisleriot/guile/2.0/fortunes.go <==
GOOF----LE-8-2.0      ] C 4   h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  ice-9	g  format	
 	 	g  initialize-playing-area	g  set-ace-high	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-blank-slot	g  add-extended-slot	g  down	g  give-status-message	g  new-game	g  set-statusbar-message	g  get-stock-no-string	g  
string-append	g  _	 f  Stock left:	!f   	"g  number->string	#g  length	$g  	get-cards	%g  empty-slot?	&g  button-pressed	'g  
droppable?	(g  
move-n-cards!	)g  button-released	*g  member	+			 	,g  
removable?	-g  get-suit	.g  get-top-card	/g  	get-value	0g  remove-card	1g  
add-to-score!	2g  
deal-cards	3g  
flip-top-card	4g  button-clicked	5g  button-double-clicked	6g  game-won	7g  	game-over	8g  hint-remove-top-card	9g  
check-hint	:f  ,Consider moving something into an empty slot	;f  Deal another round	<g  get-hint	=g  get-options	>g  
apply-options	?g  timeout	@g  set-features	Ag  droppable-feature	Bg  
set-lambdaC 5  h     ] 4	 >  "  G       h      ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4	>  "  G  4	>  "  G  4	>  "  G  4	>  "  G  4
>   "  G  		 C       g  filenamef  fortunes.scm
	
							#			3			C			U			e			h			o			x			{		 		 		 		 		 		 		 		 	!	 	#	 	 
  g  nameg  new-game CR        h   n   ] 45 6     f       g  filenamef  fortunes.scm
	&
		'			'	 		
  g  nameg  give-status-message CR !"#$     h       ] 45444
5556        g  filenamef  fortunes.scm
	)
		*				*			*		
	*	"		+			+	!		+	)		+	!		+			*	 		
  g  nameg  get-stock-no-string CR% hP     ]
$  E 
$  ;45$  C4	5$  C4	5$  C	6CC        g  slot-id
		O g  	card-list		O g  t			K g  t		(	K g  t		:	K  g  filenamef  fortunes.scm
	-
		.			/			.			0			0		"	1		(	0		4	2		:	0		K	3	 		O	  g  nameg  button-pressed C&R'(  h0      ]4 5$  4 >  "  G  CC            g  
start-slot
		+ g  	card-list		+ g  end-slot			+  g  filenamef  fortunes.scm
	5
		6			6			8	 		+	  g  nameg  button-released C)R*+%   h(      ]45$   $  C6C             g  
start-slot
		" g  	card-list		" g  end-slot			"  g  filenamef  fortunes.scm
	<
		=				=			=			=			>			=		 	?	 			"	  g  nameg  
droppable? C'R,%-./01        h   w  ] $  	$  C 645$  "  ;44 554455$  44 554455"  $  4 >  "  G  6	$  C 6       o      g  slot-id
	  g  reason	   g  filenamef  fortunes.scm
	A
		B			B			C	
		C			E			E	
	 	F		*	F	
	0	G		3	G		;	G		<	H		?	H		G	H		H	G		L	F	
	M	I		P	I		X	I		Y	J		\	J		d	J		e	I		n	F		o	L	 	M	 	N	 	N	
 	P	" 	P	  	 	  g  nameg  
removable? C,R%2+3,        hp      ]4 5$  C 
$  N4
>  "  G  4>  "  G  4	>  "  G  4	>  "  G  	6 6           g  slot-id
		l  g  filenamef  fortunes.scm
	R
		S		
	S			U	
		U			W			W		"	W		+	X		<	Y		N	Z		e	[		l	\	
 		l  g  nameg  button-clicked C4R4        h   {   ] 6s       g  slot
		  g  filenamef  fortunes.scm
	^
		_	 		  g  nameg  button-double-clicked C5R%#$        hX      ] 4
5$  J4455$  744	55$  #44	55$  44	55CCCCC       g  filenamef  fortunes.scm
	a
		b			b			c			c			c			c			b			d		"	d		*	d		+	d		/	b		1	e		4	e		<	e		=	e		A	b		C	f		F	f		N	f		O	f	 		X
  g  nameg  game-won C6R%-.      h(  ]  ] 4>   "  G  4
5$ 45$  "  4	5$  "  4	5$  "  4	5$  "  445544	55$  "  445544	55$  "  445544	55$  "  ^44	5544	55$  "  <44	5544	55$  "  44	5544	55"  C     U      g  filenamef  fortunes.scm
	h
		i			j			j			k		&	k		,	l		6	k		<	m		F	k		L	n		V	k		\	o		_	o	'	f	o		g	p		j	p	'	r	p		s	o		w	k		}	q	 	q	' 	q	 	r	 	r	' 	r	 	q	 	k	 	s	 	s	' 	s	 	t	 	t	' 	t	 	s	 	k	 	u	 	u	' 	u	 	v	 	v	' 	v	 	u	 	k	 	w	 	w	' 	w	 	x	 	x	' 	x	 	w	 	k		y		y	'	y		z		z	'	z		y		y	"	j	 >	#
  g  nameg  	game-over C7R%-./89        h   `  ]	$  C4 5$  "  )45$  "  44 554455$  )44 554455$   66 6    X      g  slot1
		| g  slot2		|  g  filenamef  fortunes.scm
	|
		}			}							
	 		(		
	. 		1 		9 		: 		= 		E 		F 		J			K 		N 		V 		W 		Z 		b 		c 		g 	
	m 		s 		z 		| 	
 		|	  g  nameg  
check-hint C9R9%#$:;   hp    ]4	5  $   C4		5  $   C4		5  $   C45  $  "  54	5$  "  4	5$  "  4	5 $  45$  "  
4455  $  "  z4	5$  "  44	55$  "  L4	5$  "  44	55$  "  4	5$  "  44	55 $  
45 "  "    $   C4
5$  C
45 C        g  t
	
n g  t
	n g  t
	2n g  t
	C  g  t	W  g  t		k  g  t
 2 g  t / g  t	 , g  t
Kn  
g  filenamef  fortunes.scm
 
	 		
 		 		 		* 		2 		> 		C 		Q 		W 		e 		k 		y 	  	  	  	  	  	#  	  	  	  	  	  	  	#  	  	  	  	  	  	  	#  	  	  	 	 	 	 	#' 	) 	6 	
8 	< 	> 	A 	
K 	W 	` 	d 	h 	j 	m 	
 7	n
  g  nameg  get-hint C<R   h   W   ] C    O       g  filenamef  fortunes.scm
 
 		
  g  nameg  get-options C=R    h   o   ]C    g       g  options
		  g  filenamef  fortunes.scm
 
 		  g  nameg  
apply-options C>R    h   S   ] C    K       g  filenamef  fortunes.scm
 
 		
  g  nameg  timeout C?R4@iAi>  "  G  Bii&i)i4i5i7i6i<i=i>i?i'i6             g  filenamef  fortunes.scm		
	
	&
	)
	-
	5
	<
	B	A

	R
>	^
	a
P	h
S	|
 
J 
 
> 
? 
 
 	
   C6 
